require 'puppet_x/enterprisemodules/transformers'
require 'puppet_x/enterprisemodules/attribute_helpers'

newproperty(:present_in) do
  include EasyType
  include PuppetX::EnterpriseModules::LdapAccess
  include PuppetX::EnterpriseModules::Transformers
  include PuppetX::EnterpriseModules::AttributeHelpers

  defaultto({})

  desc <<-EOD
    Using this property, you can manage group relations. You make sure the LDAP intry is present in a group.

    You can make sure a specific LDAP entry is part of a group. Here is
    an example:

      ldap_principal { 'ldap_server:cn=muppets,ou=muppetshow,dc=example,dc=org':
        ...
        present_in       => {
          'member'       => [
            'cn=kermit,ou=muppetshow,dc=example,dc=org',
            'cn=piggy,ou=muppetshow,dc=example,dc=org',
          ],
        },
      }

    This puppet code makes sure that `kermit` and `piggy` are part of the group
    `muppets`.


  EOD

  data_type("Optional[Hash]")

  on_modify do
    is = resource.provider.attributes
    is = {} if is == :absent
    operations = []
    added_attributes(is, should).each do |attribute|
      operations << [:add, attribute, value_to_add(should[attribute], is[attribute])]
    end
    ldap(resource[:ldap_server]).modify(resource[:distinguished_name], operations)
    nil
  end

  def insync?(_is)
    #
    # We use the value from attributes. This one is a full representation of
    # the resource actual value.
    #
    added_attributes(resource.provider.attributes, should).empty?
  end

  def change_to_s(is, should)
    is = resource.provider.attributes
    message = []
    added_attributes(is, should).each do |attribute|
      message << add_message(attribute, is[attribute], value_to_add(should[attribute], is[attribute]))
    end
    message.join(',')
  end

  def add_message(attribute, is, add)
    "Adding attribute(s) #{attribute} value(s) '#{add}' to '#{Array(is)}'"
  end

  def value_to_add(should, is)
    Array(should) - Array(is)
  end

  def added_attributes(is, should)
    attributes = changed_attributes(value.keys, is, should)
    attributes.select do |attribute|
      !(Array(should[attribute]) - Array(is[attribute])).empty?
    end
  end
end
