newparam(:purge_attributes, :boolean => true, :parent => Puppet::Parameter::Boolean) do
  include EasyType

  desc <<-EOD
    Aitomaticaly remove none specfied properies.

    When you specify the parameter `purge_properties`, properties that the server
    returns, but are not in your manifest, will be removed. Here is an example:

        ldap_principal { 'ldap_server:cn=fozzie,ou=muppetshow,dc=example,dc=org':
          ...
          purge_attributes => true,
          attributes => {
            'objectclass'  => ['top', 'inetOrgPerson'],
            'userPassword' => "{SSHA512}2ZsyGTxVyEw14Cu9D/OXpTddfy/387D/rlR6R0VVdRIz+3Wn52fSYZpKAP1S\n9J/kRbkoBiPK/9eZMOZV6cgidzEyMzQ1Njc4",
            # 'givenName'    => 'Fozzie Bear',
            'cn'           => 'fozzie',
            'sn'           => 'Fozzie',
          },
          ...
        }

    As you can see the `givenName` propery has been commented out. When the server still
    has the attribute for the principal, puppet will remove it because it is not specfied.
    When purge_attribute is **not** set, puppet will leave it like it was.

  EOD

  data_type("Optional[Boolean]")

  newvalues(true, false)
  defaultto false
end
