newparam(:transform) do
  include EasyType

  defaultto do
    ldap_server = resource.class.configuration[resource[:ldap_server]]
    if ldap_server && ldap_server['transform']
      ldap_server['transform']
    else
      {}
    end
  end

  validate do |value|
    raise "Currently: #{value}, but it should be a Hash." unless value.is_a?(::Hash)
  end

  munge do |value|
    #
    # Make all key lowercase symbols. This is the way the net-ldap returns them
    #
    ::Hash[value.map { |k, v| [k.downcase, v] }]
  end

  desc <<-EOD
    The transformation function that will be applied to specified attributes.

    Here is an example.

        ldap_principal { 'docker:cn=gonzo,dc=example,dc=org':
          ensure            => 'present',
          attributes        => {
            'sn'            => 'gonzo',
            'objectclass'   => ["top", "inetorgperson"],
            'userPassword'  => 'mysecretpassword',
            'givenName'     => 'Gonzo',
          },
          transform => {'userPassword' => 'hashed'},
        }

    In this definition, the value specified at the attribute 'userPassword', will first be presented to the Puppet function
    `hashed_compare` and then compared with the value returned from the ldap server. The specfied function will **NOT** be applied
    before sending the value to the LDAP server.

    You can use this when the LDAP server requires unhashed passwords on applying, but returns the hashed password.
    Because Puppet only applies the transform function for comparisson, you can use regular password values in your manifest.

  EOD

  data_type("Optional[Hash]")

end
