newparam(:transform) do
  include EasyType::YamlProperty

  defaultto {}

  validate do |value|
    fail "Currently: #{value}, but it should be a Hash." unless value.is_a?(::Hash)
  end

  munge do |value|
    #
    # Make all keys and values lowercase strings.
    #
    ::Hash[value.map { |k, v| [k.downcase, v.downcase] }]
  end

  desc <<-EOD
    The transformation function that will be applied to specified attributes.

    Here is an example.

        ldap_server { 'docker:cn=gonzo,dc=example,dc=org':
          ...
          replace_behaviour => ['userPassword','givenName'],
          transform => {'userPassword' => 'hashed'},
        }

   In this definition, the value specified at the attribute 'userPassword', will first be presented to the Puppet function
    `hashed_compare` and then compared with the value returned from the ldap server. The specified function will **NOT** be applied
    before sending the value to the LDAP server.

    You can use this when the LDAP server requires unhashed passwords on applying, but returns the hashed password.
    Because Puppet only applies the transform function for comparisson, you can use regular password values in your manifest.

  EOD

  data_type("Optional[Hash]")
end
